@@ -36,7 +36,6 @@
 void
 set_entry_validation_checkmark (GtkEntry *entry)
 {
-        g_object_set (entry, "caps-lock-warning", FALSE, NULL);
         gtk_entry_set_icon_from_icon_name (entry,
                                            GTK_ENTRY_ICON_SECONDARY,
                                            "object-select-symbolic");
@@ -46,10 +45,9 @@ void
 set_entry_validation_error (GtkEntry    *entry,
                             const gchar *text)
 {
-        g_object_set (entry, "caps-lock-warning", FALSE, NULL);
-        gtk_entry_set_icon_from_stock (entry,
-                                       GTK_ENTRY_ICON_SECONDARY,
-                                       GTK_STOCK_CAPS_LOCK_WARNING);
+        gtk_entry_set_icon_from_icon_name (entry,
+                                           GTK_ENTRY_ICON_SECONDARY,
+                                           "dialog-warning-symbolic");
         gtk_entry_set_icon_tooltip_text (entry,
                                          GTK_ENTRY_ICON_SECONDARY,
                                          text);
@@ -58,105 +56,9 @@ set_entry_validation_error (GtkEntry    *entry,
 void
 clear_entry_validation_error (GtkEntry *entry)
 {
-        gboolean warning;
-
-        g_object_get (entry, "caps-lock-warning", &warning, NULL);
-
-        if (warning)
-                return;
-
-        gtk_entry_set_icon_from_pixbuf (entry,
-                                        GTK_ENTRY_ICON_SECONDARY,
-                                        NULL);
-        g_object_set (entry, "caps-lock-warning", TRUE, NULL);
-}
-
-void
-popup_menu_below_button (GtkMenu   *menu,
-                         gint      *x,
-                         gint      *y,
-                         gboolean  *push_in,
-                         GtkWidget *button)
-{
-        GtkRequisition menu_req;
-        GtkTextDirection direction;
-        GtkAllocation allocation;
-
-        gtk_widget_get_preferred_size (GTK_WIDGET (menu), NULL, &menu_req);
-
-        direction = gtk_widget_get_direction (button);
-
-        gdk_window_get_origin (gtk_widget_get_window (button), x, y);
-        gtk_widget_get_allocation (button, &allocation);
-        *x += allocation.x;
-        *y += allocation.y + allocation.height;
-
-        if (direction == GTK_TEXT_DIR_LTR)
-                *x += MAX (allocation.width - menu_req.width, 0);
-        else if (menu_req.width > allocation.width)
-                *x -= menu_req.width - allocation.width;
-
-        *push_in = TRUE;
-}
-
-void
-down_arrow (GtkStyleContext *context,
-            cairo_t         *cr,
-            gint             x,
-            gint             y,
-            gint             width,
-            gint             height)
-{
-        GtkStateFlags flags;
-        GdkRGBA fg_color;
-        GdkRGBA outline_color;
-        gdouble vertical_overshoot;
-        gint diameter;
-        gdouble radius;
-        gdouble x_double, y_double;
-        gdouble angle;
-        gint line_width;
-
-        flags = gtk_style_context_get_state (context);
-
-        gtk_style_context_get_color (context, flags, &fg_color);
-        gtk_style_context_get_border_color (context, flags, &outline_color);
-
-        line_width = 1;
-        angle = G_PI / 2;
-        vertical_overshoot = line_width / 2.0 * (1. / tan (G_PI / 8));
-        if (line_width % 2 == 1)
-                vertical_overshoot = ceil (0.5 + vertical_overshoot) - 0.5;
-        else
-                vertical_overshoot = ceil (vertical_overshoot);
-        diameter = (gint) MAX (3, width - 2 * vertical_overshoot);
-        diameter -= (1 - (diameter + line_width) % 2);
-        radius = diameter / 2.;
-        x_double = floor ((x + width / 2) - (radius + line_width) / 2.) + (radius + line_width) / 2.;
-
-        y_double = (y + height / 2) - 0.5;
-
-        cairo_save (cr);
-
-        cairo_translate (cr, x_double, y_double);
-        cairo_rotate (cr, angle);
-
-        cairo_move_to (cr, - radius / 2., - radius);
-        cairo_line_to (cr,   radius / 2.,   0);
-        cairo_line_to (cr, - radius / 2.,   radius);
-
-        cairo_close_path (cr);
-
-        cairo_set_line_width (cr, line_width);
-
-        gdk_cairo_set_source_rgba (cr, &fg_color);
-
-        cairo_fill_preserve (cr);
-
-        gdk_cairo_set_source_rgba (cr, &outline_color);
-        cairo_stroke (cr);
-
-        cairo_restore (cr);
+        gtk_entry_set_icon_from_paintable (entry,
+                                           GTK_ENTRY_ICON_SECONDARY,
+                                           NULL);
 }
 
 #define MAXNAMELEN  (UT_NAMESIZE - 1)
@@ -226,16 +128,19 @@ is_valid_username (const gchar *username, gboolean parental_controls_enabled, gc
         valid = TRUE;
 
         if (!in_use && !empty && !too_long) {
-                /* First char must be a letter, and it must only composed
-                 * of ASCII letters, digits, and a '.', '-', '_'
+                /* First char must be a lower case letter, and it must only be
+                 * composed of lower case letters, digits, '-', and '_'.
                  */
                 for (c = username; *c; c++) {
-                        if (! ((*c >= 'a' && *c <= 'z') ||
-                               (*c >= 'A' && *c <= 'Z') ||
-                               (*c >= '0' && *c <= '9') ||
-                               (*c == '_') || (*c == '.') ||
-                               (*c == '-' && c != username)))
-                           valid = FALSE;
+                        if (c == username) {
+                            if (! (*c >= 'a' && *c <= 'z'))
+                               valid = FALSE;
+                        } else {
+                            if (! ((*c >= 'a' && *c <= 'z') ||
+                                   (*c >= '0' && *c <= '9') ||
+                                   (*c == '_') || (*c == '-')))
+                               valid = FALSE;
+                        }
                 }
         }
 
@@ -250,14 +155,14 @@ is_valid_username (const gchar *username, gboolean parental_controls_enabled, gc
                 else if (too_long) {
                         *tip = g_strdup_printf (_("The username is too long."));
                 }
-                else if (username[0] == '-') {
-                        *tip = g_strdup (_("The username cannot start with a “-”."));
+                else if (!(username[0] >= 'a' && username[0] <= 'z')) {
+                        *tip = g_strdup (_("The username must start with a lower case letter from a-z."));
                 }
                 else if (parental_controls_conflict) {
                         *tip = g_strdup (_("That username isn’t available. Please try another."));
                 }
                 else {
-                        *tip = g_strdup (_("The username should only consist of upper and lower case letters from a-z, digits and the following characters: . - _"));
+                        *tip = g_strdup (_("The username should only consist of lower case letters from a-z, digits, and the following characters: - _"));
                 }
         }
         else {
@@ -517,7 +422,7 @@ extract_initials_from_name (const gchar *name)
         g_string_append_unichar (initials, unichar);
 
         p = g_utf8_strrchr (normalized, -1, ' ');
-        if (p != NULL && g_utf8_next_char (p) != NULL) {
+        if (p != NULL) {
                 p = g_utf8_next_char (p);
 
                 unichar = g_utf8_get_char (p);
